# Contributing to ngdb

I probably won't accept any code for now, and raising issues isn't really
something to do yet. This is still an early work in progress that I'm
personally having fun with.

This will change and when it does this text will be replaced with something
far more sociable.

[//]: # (Contributing.md ends here)
